# Getting started

![logo](assets/logo.png)

## Introduction

Welcome to fletched!

An opinionated framework on top of Flet,
designed to significantly reduce boilerplate code
and aid in structuring a non-trivial project.

If Flet were an arrow,
fletched would give it feathers,
enabling you to aim and hit way further.

For now, it offers three libraries/submodules:
`mvp`, `routed_app` and `controls`.
They are designed to work in conjunction,
but should you only want to use one of them,
that should work just as well.

## Installation

You can install fletched by executing

```bash
poetry add fletched
```

or

```bash
pip install fletched
```

depending on how you prefer to manage your dependencies.
